@@ -838,8 +838,6 @@ class WordToken(models.Model):
         return True
 
     def getAnalysisLines(self,form):
-        if settings.DEBUG:
-            self.createPictures()
         beg,end,vow,prevSound,follSound = self.getAcousticInfo()
         outline = {'Word':self.WordType.Label}
         outline['Vowel'] = self.WordType.getStressVowel()
