@@ -283,7 +283,7 @@ def AnalyzeSpeaker(baseqs,speakNum,form):
     #updatelogfile(logfilename, "All done!")
 
 @task()
-def doBasicAnalysis(logfilename,form):
+def doBasicAnalysis(form):
     goodWords = ['back', 'bad', 'badge', 'bag', 'ball', 'bar', 'bare', 'base', 'bash', 'bass', 'bat', 'bath', 'beach', 'bean', 'bear', 'beat',
                  'bed', 'beer', 'bell', 'berth', 'big', 'bike', 'bill', 'birth', 'bitch', 'bite', 'boat', 'bob', 'boil', 'bomb', 'book', 'boom', 'boon',
                  'boss', 'bought', 'bout', 'bowl', 'buck', 'bum', 'burn', 'bus', 'bush', 'cab', 'cad', 'cake', 'calf', 'call', 'came', 'cap',
